package com.ozs.web.controller.accountmanagment;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.ozs.common.annotation.Log;
import com.ozs.common.core.controller.BaseController;
import com.ozs.common.core.domain.AjaxResult;
import com.ozs.common.enums.BusinessType;
import com.ozs.common.utils.StringUtils;
import com.ozs.service.entity.BaseCameraVersion;
import com.ozs.service.entity.vo.BaseCameraVersionVo;
import com.ozs.service.service.BaseCameraVersionService;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 相机版本管理
 * @Author : sunhh
 * @create 2023/4/24 11:00
 */
@Slf4j
@RestController
@RequestMapping("/baseCameraVersion")
public class BaseCameraVersionController extends BaseController {

    @Autowired
    private BaseCameraVersionService baseCameraVersionService;

    /**
     * 相机版本管理 分页查询
     *
     * @param baseCameraVersionVo
     * @return
     */
    @ApiOperation(value = "相机版本管理 分页查询")
    @PostMapping("/cameraVersionList")
    @Log(title = "相机版本管理", businessType = BusinessType.SELECT)
    public AjaxResult cameraVersionList(@RequestBody BaseCameraVersionVo baseCameraVersionVo) {
        IPage<BaseCameraVersionVo> baseCameraVersionIPage = baseCameraVersionService.cameraVersionList(baseCameraVersionVo);
        return AjaxResult.success(baseCameraVersionIPage);
    }

    /**
     * 相机版本管理 新增
     *
     * @param baseCameraVersion
     * @return
     */
    @ApiOperation(value = "相机版本管理 新增")
    @PostMapping("/cameraVersionAdd")
    @Log(title = "机车信息管理", businessType = BusinessType.INSERT)
    public AjaxResult cameraVersionAdd(@RequestBody BaseCameraVersion baseCameraVersion) {
        if (StringUtils.isEmptySunhh(baseCameraVersion) || StringUtils.isEmptySunhh(baseCameraVersion.getVersionNum())
                || StringUtils.isEmptySunhh(baseCameraVersion.getVersionName())
                || StringUtils.isEmptySunhh(baseCameraVersion.getVersionAddress())) {
            return AjaxResult.error("相机版本号、版本名称、版本地址不能为空！");
        }
        return baseCameraVersionService.cameraVersionAdd(baseCameraVersion, getUserId());
    }

    /**
     * 相机版本管理 删除
     *
     * @param ids
     * @return
     */
    @ApiOperation(value = "相机版本管理 删除")
    @DeleteMapping("/cameraVersionDelete/{ids}")
    @Log(title = "相机版本管理", businessType = BusinessType.DELETE)
    public AjaxResult cameraVersionDelete(@PathVariable List<Long> ids) {
        if (StringUtils.isEmptySunhh(ids)) {
            return AjaxResult.error("删除ID不能为空！");
        }
        boolean delete = baseCameraVersionService.removeByIds(ids);
        if (delete) {
            return AjaxResult.success();
        } else {
            return AjaxResult.error();
        }
    }
}
